var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'appendix.xml',
'whats_new.xml',
'whats_new_12.xml'
];
var list_down3 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'preprocessor.xml',
'multi_thread.xml',
'utility.xml',
'ipopt_solve.xml',
'example.xml',
'speed.xml',
'appendix.xml'
];
var list_down2 = [
'faq.xml',
'theory.xml',
'glossary.xml',
'bib.xml',
'wish_list.xml',
'whats_new.xml',
'deprecated.xml',
'compare_c.xml',
'numeric_ad.xml',
'addon.xml',
'license.xml'
];
var list_down1 = [
'whats_new_15.xml',
'whats_new_14.xml',
'whats_new_13.xml',
'whats_new_12.xml',
'whats_new_11.xml',
'whats_new_10.xml',
'whats_new_09.xml',
'whats_new_08.xml',
'whats_new_07.xml',
'whats_new_06.xml',
'whats_new_05.xml',
'whats_new_04.xml',
'whats_new_03.xml'
];
var list_current0 = [
'whats_new_12.xml#Introduction',
'whats_new_12.xml#12-30',
'whats_new_12.xml#12-29',
'whats_new_12.xml#12-28',
'whats_new_12.xml#12-27',
'whats_new_12.xml#12-26',
'whats_new_12.xml#12-23',
'whats_new_12.xml#12-22',
'whats_new_12.xml#12-20',
'whats_new_12.xml#12-19',
'whats_new_12.xml#12-17',
'whats_new_12.xml#12-15',
'whats_new_12.xml#12-14',
'whats_new_12.xml#12-13',
'whats_new_12.xml#11-28',
'whats_new_12.xml#11-21',
'whats_new_12.xml#11-20',
'whats_new_12.xml#11-17',
'whats_new_12.xml#11-16',
'whats_new_12.xml#11-14',
'whats_new_12.xml#11-09',
'whats_new_12.xml#11-06',
'whats_new_12.xml#11-04',
'whats_new_12.xml#10-31',
'whats_new_12.xml#10-30',
'whats_new_12.xml#10-25',
'whats_new_12.xml#10-24',
'whats_new_12.xml#10-12',
'whats_new_12.xml#10-04',
'whats_new_12.xml#10-03',
'whats_new_12.xml#10-02',
'whats_new_12.xml#09-24',
'whats_new_12.xml#09-11',
'whats_new_12.xml#08-05',
'whats_new_12.xml#07-30',
'whats_new_12.xml#07-08',
'whats_new_12.xml#07-07',
'whats_new_12.xml#07-05',
'whats_new_12.xml#07-04',
'whats_new_12.xml#07-03',
'whats_new_12.xml#07-02',
'whats_new_12.xml#07-01',
'whats_new_12.xml#06-17',
'whats_new_12.xml#06-16',
'whats_new_12.xml#06-15',
'whats_new_12.xml#06-12',
'whats_new_12.xml#06-10',
'whats_new_12.xml#06-09',
'whats_new_12.xml#06-08',
'whats_new_12.xml#06-07',
'whats_new_12.xml#06-05',
'whats_new_12.xml#06-04',
'whats_new_12.xml#06-03',
'whats_new_12.xml#06-02',
'whats_new_12.xml#06-01',
'whats_new_12.xml#05-31',
'whats_new_12.xml#05-30',
'whats_new_12.xml#05-29',
'whats_new_12.xml#05-27',
'whats_new_12.xml#05-24',
'whats_new_12.xml#04-19',
'whats_new_12.xml#04-18',
'whats_new_12.xml#04-17',
'whats_new_12.xml#04-10',
'whats_new_12.xml#04-06',
'whats_new_12.xml#04-05',
'whats_new_12.xml#04-01',
'whats_new_12.xml#03-27',
'whats_new_12.xml#03-26',
'whats_new_12.xml#03-23',
'whats_new_12.xml#03-21',
'whats_new_12.xml#03-17',
'whats_new_12.xml#03-11',
'whats_new_12.xml#03-03',
'whats_new_12.xml#03-02',
'whats_new_12.xml#02-11',
'whats_new_12.xml#02-10',
'whats_new_12.xml#02-09',
'whats_new_12.xml#01-30',
'whats_new_12.xml#01-27',
'whats_new_12.xml#01-24',
'whats_new_12.xml#01-23',
'whats_new_12.xml#01-20',
'whats_new_12.xml#01-19',
'whats_new_12.xml#01-16',
'whats_new_12.xml#01-15',
'whats_new_12.xml#01-12',
'whats_new_12.xml#01-07',
'whats_new_12.xml#01-02'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}
